==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/sybase/sybase/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Sybase Python Driver")
url = "http://www.object-craft.com.au/projects/sybase/"
doc = """
Description
-----------
Driver to provide access to data via Dave Cole's Sybase ASE/Python Driver.

Support
-------
Supported Platforms:

  - Linux/(BSD?)
  - Solaris 2.6/5.6/8
  - Irix
  - HP-UX
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* service  -- This is the Sybase DSN for your connection  (required)
* dbname   -- This is the Sybase database to use (optional)

Examples
--------
  provider=sybase         # Use the Sybase adapter
  service=DSNname         # The Sybase DSN name
  dbname=mydb             # The name of the Sybase database

Notes
-----
1. This driver has not been fully tested.  If you are successfully using
   this driver, please let us know.

2. This driver does not yet support schema introspection, so you will not
   be able to use Wizards in GNUe Designer.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/sybase/sybase/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("Sybase Python Driver")
url = "http://www.object-craft.com.au/projects/sybase/"
doc = """
Description
-----------
Driver to provide access to data via Dave Cole's Sybase ASE/Python Driver.

Support
-------
Supported Platforms:

  - Linux/(BSD?)
  - Solaris 2.6/5.6/8
  - Irix
  - HP-UX
  - MS Windows 98/NT/2000/XP

Connection Properties
---------------------
* service  -- This is the Sybase DSN for your connection  (required)
* dbname   -- This is the Sybase database to use (optional)

Examples
--------
  provider=sybase         # Use the Sybase adapter
  service=DSNname         # The Sybase DSN name
  dbname=mydb             # The name of the Sybase database

Notes
-----
1. This driver is currently unmaintained and not functional.
"""
